@@ -7,13 +7,9 @@ use Exporter ;
 
 use constant HTTP_QUOTES => "\"'"  ;
 use constant HTTP_WHITESPACE => " \r\n\t"  ;
-use constant NE_ALLOC_H =>  ;
 use constant NE_AUTH => (4)  ;
 use constant NE_AUTHPROXY => (5)  ;
-use constant NE_AUTH_H =>  ;
-use constant NE_BASIC_H =>  ;
 use constant NE_CONNECT => (8)  ;
-use constant NE_COOKIES_H =>  ;
 use constant NE_DBG_FLUSH => (1<<30)  ;
 use constant NE_DBG_HTTP => (1<<1)  ;
 use constant NE_DBG_HTTPAUTH => (1<<3)  ;
@@ -27,9 +23,9 @@ use constant NE_DBG_XMLPARSE => (1<<6)  ;
 use constant NE_DEPTH_INFINITE => (2)  ;
 use constant NE_DEPTH_ONE => (1)  ;
 use constant NE_DEPTH_ZERO => (0)  ;
+use constant NE_ELM_UNUSED => (100)  ;
 use constant NE_ELM_207_UNUSED => (NE_ELM_UNUSED + 100)  ;
 use constant NE_ELM_207_first => (NE_ELM_UNUSED)  ;
-use constant NE_ELM_UNUSED => (100)  ;
 use constant NE_ELM_href => (NE_ELM_207_first + 3)  ;
 use constant NE_ELM_multistatus => (NE_ELM_207_first)  ;
 use constant NE_ELM_prop => (NE_ELM_207_first + 5)  ;
@@ -41,28 +37,19 @@ use constant NE_ELM_status => (NE_ELM_207_first + 6)  ;
 use constant NE_ELM_unknown => -1  ;
 use constant NE_ERROR => (1)  ;
 use constant NE_FAILED => (10)  ;
-use constant NE_LOCKS_H =>  ;
 use constant NE_LOOKUP => (3)  ;
 use constant NE_OK => (0)  ;
-use constant NE_PROPS_H =>  ;
 use constant NE_PROXYAUTH => (7)  ;
 use constant NE_REDIRECT => (12)  ;
-use constant NE_REDIRECT_H =>  ;
-use constant NE_REQUEST_H =>  ;
 use constant NE_RETRY => (11)  ;
 use constant NE_SERVERAUTH => (6)  ;
 use constant NE_SESSION_H => 1  ;
-use constant NE_SOCKET_H =>  ;
-use constant NE_STRING_H =>  ;
 use constant NE_TIMEOUT => (9)  ;
 use constant NE_TIMEOUT_INFINITE => -1  ;
 use constant NE_TIMEOUT_INVALID => -2  ;
-use constant NE_URI_H =>  ;
-use constant NE_UTILS_H =>  ;
 use constant NE_XML_CDATA => (1<<1)  ;
 use constant NE_XML_COLLECT => ((1<<2) | NE_XML_CDATA)  ;
 use constant NE_XML_DECLINE => (-2)  ;
-use constant NE_XML_H =>  ;
 use constant NE_XML_INVALID => (-1)  ;
 use constant NE_XML_MIXED => (1<<4)  ;
 use constant NE_XML_UTF8DECODE => (1<<3)  ;
